"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateOptions = void 0;
const utils_validation_1 = require("@docusaurus/utils-validation");
function pluginDatadogRum(context, { clientToken, applicationId, service, env }) {
    service = service ?? "docusaurus";
    env = env ?? process.env.NODE_ENV ?? "dev";
    return {
        name: "docusaurus-plugin-for-datadog-rum",
        injectHtmlTags() {
            if (!clientToken || !applicationId) {
                return {};
            }
            return {
                headTags: [
                    {
                        tagName: "script",
                        innerHTML: `(function(h,o,u,n,d) {
  h=h[d]=h[d]||{q:[],onReady:function(c){h.q.push(c)}}
  d=o.createElement(u);d.async=1;d.src=n
  n=o.getElementsByTagName(u)[0];n.parentNode.insertBefore(d,n)
})(window,document,'script','https://www.datadoghq-browser-agent.com/datadog-rum.js','DD_RUM')
DD_RUM.onReady(function() {
  DD_RUM.init({
    clientToken: '${clientToken}',
    applicationId: '${applicationId}',
    site: 'datadoghq.com',
    service: '${service}',
    env: '${env}',
    // Specify a version number to identify the deployed version of your application in Datadog 
    // version: '1.0.0',
    sampleRate: 100,
    trackInteractions: true,
  })
})`,
                    },
                ],
            };
        },
    };
}
exports.default = pluginDatadogRum;
const pluginOptionsSchema = utils_validation_1.Joi.object({
    clientToken: utils_validation_1.Joi.string().required(),
    applicationId: utils_validation_1.Joi.string().required(),
    service: utils_validation_1.Joi.string().default("docusaurus"),
    env: utils_validation_1.Joi.string().default(process.env.NODE_ENV ?? "dev"),
});
function validateOptions({ validate, options, }) {
    return validate(pluginOptionsSchema, options);
}
exports.validateOptions = validateOptions;
